@@ -2,17 +2,17 @@
 
 import asyncio
 import json
-from json.decoder import JSONDecodeError
 import logging
-from asyncio import Lock, Condition
+from asyncio import Condition, Lock
 from enum import Enum
-from typing import Any, Dict, List, Union, Optional
+from json.decoder import JSONDecodeError
+from typing import Any, Dict, List, Optional, Union
 
 import aiohttp
 from async_timeout import timeout
 
-from .zone import Zone
 from .power import Power
+from .zone import Zone
 
 _LOG = logging.getLogger("pizone.controller")
 
@@ -45,9 +45,6 @@ class Controller:
     REQUEST_TIMEOUT = 3
     """Time to wait for results from server."""
 
-    CONNECT_RETRY_TIMEOUT = 20
-    """Cool-down period for retrying to connect to the controller"""
-
     REFRESH_INTERVAL = 25.0
     """Interval between refreshes of data."""
 
@@ -141,17 +138,23 @@ class Controller:
 
             # pylint: disable=broad-except
             try:
-                await self._refresh_all()
                 _LOG.debug("Polling unit %s.", self._device_uid)
+                await self._refresh_all()
             except ConnectionError:
                 _LOG.debug("Poll failed due to exeption.", exc_info=True)
             except Exception:
                 _LOG.error("Unexpected exception", exc_info=True)
 
-    async def _rescan(self) -> None:
+    async def refresh(self) -> None:
+        """Queue a refresh of all controller data."""
         async with self._scan_condition:
             self._scan_condition.notify()
 
+    @property
+    def connected(self) -> bool:
+        """True if the controller is currently connected"""
+        return self._fail_exception is None
+
     @property
     def power(self) -> Optional[Power]:
         """Power info"""
@@ -358,11 +361,11 @@ class Controller:
 
     async def _refresh_all(self, notify: bool = True) -> None:
         zones = int(self._system_settings["NoOfZones"])
-        await asyncio.gather(
-            self._refresh_system(notify),
-            self._refresh_power(notify),
-            *[self._refresh_zone_group(i, notify) for i in range(0, zones, 4)]
-        )
+        # this has to be done sequentially
+        await self._refresh_system(notify)
+        await self._refresh_power(notify)
+        for i in range(0, zones, 4):
+            await self._refresh_zone_group(i, notify)
 
     async def _refresh_system(self, notify: bool = True) -> None:
         """Refresh the system settings."""
@@ -424,7 +427,7 @@ class Controller:
         # Update state and trigger rescan
         self._system_settings[state] = value
         self._discovery.controller_update(self)
-        await self._rescan()
+        await self.refresh()
 
     def _ensure_connected(self) -> None:
         if self._fail_exception:
@@ -491,7 +494,7 @@ class Controller:
         # For some reason aiohttp fragments post requests, which causes
         # the server to fail disgracefully. Implimented rough and dirty
         # HTTP POST client.
-        loop = self.discovery.loop
+        loop = asyncio.get_running_loop()
         on_complete = loop.create_future()
         device_ip = self.device_ip
         response = []
@@ -534,7 +537,15 @@ class Controller:
                         )
                     )
                 elif len(lines) > 2 and len(lines[-2]) == 0:
-                    on_complete.set_result(lines[-1])
+                    result = lines[-1]
+                    if len(result) > 7 and result[:6] == "{ERROR":
+                        on_complete.set_exception(
+                            ConnectionError(f"Server returned error state {result}")
+                        )
+                        return
+                    if len(result) > 4 and result[-4:] == "{OK}":
+                        result = result[:-4]
+                    on_complete.set_result(result)
                 else:
                     on_complete.set_result(None)
 
@@ -556,6 +567,8 @@ class Controller:
 
             return on_complete.result()
 
+        except ConnectionError:
+            raise
         except (OSError, asyncio.TimeoutError, aiohttp.ClientError) as ex:
             self._failed_connection(ex)
             raise ConnectionError("Unable to connect to controller") from ex
