@@ -9,7 +9,7 @@ from __future__ import annotations
 import json
 import logging
 from enum import IntEnum, unique
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Set
+from typing import Any, Dict, Iterable, List, Optional, Set, Tuple
 
 _LOG = logging.getLogger("pizone.power")
 
@@ -206,17 +206,7 @@ class Power:
         datas = await self._controller._send_command_async(
             "PowerRequest", {"Type": req_type, "No": 0, "No1": 0}
         )
-
-        try:
-            data = json.loads(datas)
-        except json.decoder.JSONDecodeError as ex:
-            if datas[-4:] == "{OK}":
-                data = json.loads(datas[:-4])
-            else:
-                _LOG.error('Decode error for "%s"', datas, exc_info=True)
-                raise ConnectionError(
-                    "Unable to decode response, see error log."
-                ) from ex
+        data = json.loads(datas)
         return data[result]
 
     @property
